# Tripadvisor-Scraper-Project
<<<<<<< HEAD
  Webscrping project to get data from Tripadvisor.co.uk and geting information about hotels from city.
=======

## Overview
This is web scaping project to scape data from TripAdvisor website.
- We are scaping data of Hotels details.
    - Hotel Name 
    - Address 
    - Review 
    - Ratings
    - Amenities provide by that Hotel.

>>>>>>> dev
